Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: tools/create_sdk.py

Issue 9462001: Unify most of our utf8 implementations. This takes the implementation (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: '' Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/create_sdk.py
===================================================================
--- tools/create_sdk.py (revision 4630)
+++ tools/create_sdk.py (working copy)
@@ -41,8 +41,7 @@
# ........{frog}/
# ......uri/
# ........uri.dart
-# ......utf8/
-# ........utf8.dart
+# ......utf/
# ......(more will come here)
# ....util/
# ......(more will come here)
@@ -259,10 +258,10 @@
'*monkey*'))
#
# Create and populate lib/{json, uri, utf8} .
#
- for library in ['json', 'uri', 'utf8']:
+ for library in ['json', 'uri', 'utf']:
src_dir = join(HOME, 'lib', library)
dest_dir = join(LIB, library)
os.makedirs(dest_dir)
@@ -259,10 +258,10 @@
'*monkey*'))
#
- # Create and populate lib/{json, uri, utf8} .
+ # Create and populate lib/{json, uri, utf} .
#

Powered by Google App Engine
This is Rietveld 408576698